pub struct ChangeSet {
pub rows: Vec<RowChange>,
pub edges: Vec<EdgeChange>,
pub vectors: Vec<VectorChange>,
pub ddl: Vec<DdlChange>,
}Expand description
A set of changes extracted from a database since a given LSN.
Fields
rows: Vec<RowChange>edges: Vec<EdgeChange>vectors: Vec<VectorChange>ddl: Vec<DdlChange>Implementations
Sourceimpl ChangeSet
impl ChangeSet
Sourcepub fn filter_by_direction(
&self,
directions: &HashMap<String, SyncDirection>,
include: &[SyncDirection],
) -> ChangeSet
pub fn filter_by_direction( &self, directions: &HashMap<String, SyncDirection>, include: &[SyncDirection], ) -> ChangeSet
Filters this changeset to only include tables matching the given directions.